dockerutil

package module
v0.0.0-...-fbd124f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 20, 2018 License: MIT Imports: 8 Imported by: 0

README

dockerutil

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Getenv

func Getenv(key string) string

Getenv will load the config from 1) environment, 2) Docker secret, 3) Docker config

func HandleDockerStop

func HandleDockerStop(handler func()) chan os.Signal

HandleDockerStop will run the passed function on a SIGTERM signal

func HandleSignalChannel

func HandleSignalChannel(sigChan chan os.Signal, handler func())

HandleSignalChannel will run the passed function when the signal channel fires

func StopServers

func StopServers(ctx context.Context, servers ...*http.Server) chan error

StopServers will

Types

This section is empty.

Jump to